==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/ScatterSplineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeriesView = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dj = new Path();
            this.di = new Path();
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ua = Defaults.e;
            }
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            this.di.an = this.dj.an;
            let a = this.br();
            this.di._stroke = a;
            this.di.ad = this.e.hk + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.di);
                }
                else {
                    a.t(this.dj);
                }
            }
        }
        c7(a) {
            super.c7(a);
            this.dj.an = null;
            this.di.an = null;
        }
        an(a) {
            super.an(a);
            this.e.a9.exportPathData(a, this.dj, "shape", ["Main"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s6 = a;
            this.e.ir = 3;
            this.e.is = 1;
            this.e.it = 4;
            this.e.gj = false;
        }
    }
    ScatterSplineSeriesView.$t = /*@__PURE__*/ markType(ScatterSplineSeriesView, 'ScatterSplineSeriesView', ScatterBaseView.$);
    return ScatterSplineSeriesView;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ScatterSplineSeriesView.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBaseView } from "./ScatterBaseView";
import { Path } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { markType } from "igniteui-react-core";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSplineSeriesView = /*@__PURE__*/ (() => {
    class ScatterSplineSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dl = new Path();
            this.dk = new Path();
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.w5 = Defaults.e;
            }
        }
        bd() {
            super.bd();
        }
        be() {
            super.be();
            this.dk.an = this.dl.an;
            let a = this.br();
            this.dk._stroke = a;
            this.dk.ad = this.e.id + 3;
        }
        a8(a, b) {
            super.a8(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.dk);
                }
                else {
                    a.t(this.dl);
                }
            }
        }
        c9(a) {
            super.c9(a);
            this.dl.an = null;
            this.dk.an = null;
        }
        an(a) {
            super.an(a);
            this.e.bc.exportPathData(a, this.dl, "shape", ["Main"]);
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vx = a;
            this.e.jl = 3;
            this.e.jm = 1;
            this.e.jn = 4;
            this.e.hb = false;
        }
    }
    ScatterSplineSeriesView.$t = /*@__PURE__*/ markType(ScatterSplineSeriesView, 'ScatterSplineSeriesView', ScatterBaseView.$);
    return ScatterSplineSeriesView;
})();
